@@ -222,6 +222,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
                 self.set_result(_("more than %d redirections, aborting") %
                                 self.max_redirects, valid=False)
                 self.close_response()
+                self.do_check_content = False
                 return
             if self.do_fallback(self.response.status):
                 self.fallback_to_get()
@@ -350,9 +351,6 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
         # note: urlparts has to be a list
         self.urlparts = urlparts
         self.build_url_parts()
-        # check cache again on the changed URL
-        if self.aggregate.urlqueue.checked_redirect(redirected, self):
-            return -1
         # store cookies from redirect response
         self.store_cookies()
         # new response data
@@ -463,17 +461,6 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
             return default
         return unicode_safe(value, encoding=HEADER_ENCODING)
 
-    def get_alias_cache_data (self):
-        """
-        Return all data values that should be put in the cache,
-        minus redirection warnings.
-        """
-        data = self.get_cache_data()
-        data["warnings"] = [
-            x for x in self.warnings if x[0] != WARN_HTTP_MOVED_PERMANENT]
-        data["info"] = self.info
-        return data
-
     def check_response (self):
         """Check final result and log it."""
         if self.response.status >= 400:
@@ -604,7 +591,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
         host = self.urlparts[1]
         port = urlutil.default_ports.get(scheme, 80)
         host, port = urlutil.splitport(host, port)
-        path = self.urlparts[2]
+        path = self.urlparts[2] or u"/"
         self.cookies = self.aggregate.cookies.get(scheme, host, port, path)
         if not self.cookies:
             return
@@ -629,6 +616,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
             else:
                 log.debug(LOG_CHECK, "Discard too-long cookie %r", cookievalue)
         if headervalue:
+            log.debug(LOG_CHECK, "Sending cookie header %s:%s", headername, headervalue)
             self.url_connection.putheader(headername, headervalue)
 
     def get_http_object (self, scheme, host, port):
@@ -671,7 +659,9 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
         if self.method != "GET" or self.response is None:
             self.method = "GET"
             self._try_http_response()
-            self.follow_redirections(set_result=False)
+            num = self.follow_redirections(set_result=False)
+            if not (0 <= num <= self.max_redirects):
+                raise LinkCheckerError(_("Redirection error"))
             # Re-read size info, since the GET request result could be different
             # than a former HEAD request.
             self.add_size_info()
@@ -741,21 +731,25 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
         @return: True if URL points to HTML file
         @rtype: bool
         """
-        if not (self.valid and self.headers):
+        if not self.valid:
             return False
         mime = self.get_content_type()
         if self.ContentMimetypes.get(mime) != "html":
             return False
-        return self.encoding_supported()
+        if self.headers:
+            return self.encoding_supported()
+        return True
 
     def is_css (self):
         """Return True iff content of this url is CSS stylesheet."""
-        if not (self.valid and self.headers):
+        if not self.valid:
             return False
         mime = self.get_content_type()
         if self.ContentMimetypes.get(mime) != "css":
             return False
-        return self.encoding_supported()
+        if self.headers:
+            return self.encoding_supported()
+        return True
 
     def is_http (self):
         """
@@ -775,7 +769,9 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport, pooledc
         """
         if not (self.valid and self.headers):
             return False
-        if self.get_content_type() not in self.ContentMimetypes:
+        ctype = self.get_content_type()
+        if ctype not in self.ContentMimetypes:
+            log.debug(LOG_CHECK, "URL with content type %r is not parseable", ctype)
             return False
         return self.encoding_supported()
 
