@@ -179,8 +179,6 @@ class UrlBase (object):
         # the result message string and flag
         self.result = u""
         self.has_result = False
-        # cached or not
-        self.cached = False
         # valid or not
         self.valid = True
         # list of warnings (without duplicates)
@@ -333,7 +331,7 @@ class UrlBase (object):
             # do not copy anchor warnings, since the current anchor
             # might have changed
             if anchor_changed and tag == WARN_URL_ANCHOR_NOT_FOUND:
-                pass
+                continue
             self.add_warning(msg, tag=tag)
         for info in cache_data["info"]:
             self.add_info(info)
@@ -342,12 +340,9 @@ class UrlBase (object):
         self.dlsize = cache_data["dlsize"]
         self.anchors = cache_data["anchors"]
         self.content_type = cache_data["content_type"]
-        self.cached = True
         if anchor_changed and self.valid:
             # recheck anchor
-            if self.check_anchor():
-                # a new warning has been added - remove cached flag
-                self.cached = False
+            self.check_anchor()
 
     def get_cache_data (self):
         """Return all data values that should be put in the cache."""
@@ -363,12 +358,6 @@ class UrlBase (object):
                 "content_type": self.get_content_type(),
                }
 
-    def get_alias_cache_data (self):
-        """Return all data values that should be put in the cache.
-        Intended to be overridden by subclasses that handle aliases.
-        """
-        return self.get_cache_data()
-
     def set_cache_keys (self):
         """
         Set keys for URL checking and content recursion.
@@ -379,7 +368,11 @@ class UrlBase (object):
         assert isinstance(self.cache_content_key, unicode), self
         log.debug(LOG_CACHE, "Content cache key %r", self.cache_content_key)
         # construct cache key
-        self.cache_url_key = self.cache_content_key
+        if self.aggregate.config["anchors"]:
+            # add anchor to cache key
+            self.cache_url_key = urlutil.urlunsplit(self.urlparts[:4]+[self.anchor or u""])
+        else:
+            self.cache_url_key = self.cache_content_key
         assert isinstance(self.cache_url_key, unicode), self
         log.debug(LOG_CACHE, "URL cache key %r", self.cache_url_key)
 
@@ -577,18 +570,19 @@ class UrlBase (object):
         """
         An exception occurred. Log it and set the cache flag.
         """
-        etype, value = sys.exc_info()[:2]
-        log.debug(LOG_CHECK, "Error in %s: %s %s", self.url, etype, value, exception=True)
+        etype, evalue = sys.exc_info()[:2]
+        log.debug(LOG_CHECK, "Error in %s: %s %s", self.url, etype, evalue, exception=True)
         # note: etype must be the exact class, not a subclass
         if (etype in ExcNoCacheList) or \
-           (etype == socket.error and value.args[0]==errno.EBADF) or \
-            not value:
+           (etype == socket.error and evalue.args[0]==errno.EBADF) or \
+            not evalue:
             # EBADF occurs when operating on an already socket
             self.caching = False
+        # format unicode message "<exception name>: <error message>"
         errmsg = unicode(etype.__name__)
-        if unicode(value):
-            # use Exception class name
-            errmsg += u": %s" % unicode(value)
+        uvalue = strformat.unicode_safe(evalue)
+        if uvalue:
+            errmsg += u": %s" % uvalue
         # limit length to 240
         return strformat.limit(errmsg, length=240)
 
@@ -694,8 +688,11 @@ class UrlBase (object):
         enc = lambda anchor: urlutil.url_quote_part(anchor, encoding=self.encoding)
         if any(x for x in self.anchors if enc(x[0]) == self.anchor):
             return
-        anchornames = sorted(set(u"`%s'" % x[0] for x in self.anchors))
-        anchors = u", ".join(anchornames)
+        if self.anchors:
+            anchornames = sorted(set(u"`%s'" % x[0] for x in self.anchors))
+            anchors = u", ".join(anchornames)
+        else:
+            anchors = u"-"
         args = {"name": self.anchor, "anchors": anchors}
         msg = u"%s %s" % (_("Anchor `%(name)s' not found.") % args,
                           _("Available anchors: %(anchors)s.") % args)
@@ -1137,17 +1134,22 @@ class UrlBase (object):
         if self.base_ref is not None:
             assert isinstance(self.base_ref, unicode), self
         assert isinstance(self.name, unicode), self
+        if self.anchor is not None:
+            assert isinstance(self.anchor, unicode), self
+        if self.cache_url_key is not None:
+            assert isinstance(self.cache_url_key, unicode), self
         return sep.join([
             u"%s link" % self.scheme,
             u"base_url=%r" % self.base_url,
             u"parent_url=%r" % self.parent_url,
             u"base_ref=%r" % self.base_ref,
-            u"recursion_level=%s" % self.recursion_level,
+            u"recursion_level=%d" % self.recursion_level,
             u"url_connection=%s" % self.url_connection,
             u"line=%d" % self.line,
             u"column=%d" % self.column,
             u"name=%r" % self.name,
             u"anchor=%r" % self.anchor,
+            u"cache_key=%r" % self.cache_url_key,
            ])
 
     def get_intern_pattern (self, url=None):
@@ -1197,8 +1199,6 @@ class UrlBase (object):
         The transport object must contain these attributes:
         - url_data.valid: bool
           Indicates if URL is valid
-        - url_data.cached: bool
-          Indicates if URL data has been loaded from cache.
         - url_data.result: unicode
           Result string
         - url_data.warnings: list of tuples (tag, warning message)
@@ -1236,7 +1236,6 @@ class UrlBase (object):
         """
         return dict(valid=self.valid,
           extern=self.extern[0],
-          cached=self.cached,
           result=self.result,
           warnings=self.warnings[:],
           name=self.name or u"",
@@ -1273,7 +1272,6 @@ def filter_tidy_errors (errors):
 urlDataAttr = [
     'valid',
     'extern',
-    'cached',
     'result',
     'warnings',
     'name',
